@@ -2,7 +2,6 @@
 
 from mc_mod_getter import __project_urls__
 from mc_mod_getter.utils.ApiHandler import ApiHandler
-from pathlib import Path
 import logging
 import click
 import yaml
@@ -20,17 +19,13 @@ def main(file,verbose):
 
     logging.info(f'Using yaml file: {mods_yaml}')
 
-    mods_dict = yaml.safe_load(open(mods_yaml, 'r')).items()
-    
-    for host, mod_info in mods_dict:
-        mod_list = mod_info.pop('mods')
+    yaml_info = dict(yaml.safe_load(open(mods_yaml, 'r')).items())
+    hosts = yaml_info.pop('mods')
 
-        if not mod_info.get('mod_dir',None):
-            mod_info['mod_dir'] = str(Path.home() / 'Downloads')
-
-        logging.info(f'Downloading mods to: {mod_info["mod_dir"]}')
-
-        api_handler = ApiHandler(host, **mod_info)
+    logging.info(f'Downloading mods to: {yaml_info["mod_dir"]}')
+    for host, mod_list in hosts.items():
+        logging.info(f'Downloading Mods from: {host}')
+        api_handler = ApiHandler(host.lower(),**yaml_info)
 
         for mod in mod_list:
             api_handler.download_mod(mod)
