@@ -3,9 +3,9 @@
 """Information about this version release
 """
 
-__version__ = '1.1.0'
+__version__ = '1.1.2'
 __title__ = 'mc-mod-getter'
-__description__ = 'Easy Download & Update Mods for Minecraft'
+__description__ = 'Download & Update Mods for Minecraft'
 __user__ = 'mgutierrezz'
 __url__ = f'https://github.com/{__user__}/{__title__}'
 __author__ = 'Michael Gutierrez'
